@@ -68,7 +68,7 @@ as_latex.spar <- function(
 ){
   # the latex of a spork is the sequential
   # combination of tokens.
-  # tokens separated by _ or ^ or . are non-printing
+  # Tokens _ or ^ or . are non-printing
   # but trigger nesting or un-nesting.
   # Whitespace and recognized escapes are supplied literally.
   # unescaped '*' is promoted to \code{\cdot}.
@@ -315,26 +315,26 @@ latexToken <- function(
     'N','\\Xi','O','\\Pi','P','\\Sigma','T',
     '\\Upsilon','\\Phi','X','\\Psi','\\Omega'
   )
-  extra <- c(
+  extra <- c( # these are things you can say in plotmath
     'Upsilon1','varepsilon','omega1',
     'theta1', 'phi1', 'sigma1',
     'vartheta','varphi','varsigma',
     'stigma', 'varrho','varpi'
   )
 
-  names(extra) <- c(
+  names(extra) <- c( # these are things you can say in tex
     '\\Upsilon','\\varepsilon','\\varpi',
     '\\vartheta','\\varphi','\\varsigma',
     '\\vartheta','\\varphi','\\varsigma',
     '\\varsigma', '\\varrho','\\varpi'
   )
-  escape <- function(x,pattern,replace)sub(
-    fixed = TRUE,
-    pattern,
-    replace[match(pattern,replace)],
-    x
-  )
 
+  # escape <- function(x,pattern,replace)sub(
+  #   fixed = TRUE,
+  #   pattern,
+  #   replace[match(pattern,replace)],
+  #   x
+  # )
 
   ### specials
   input <- x
